@@ -1,9 +1,10 @@
 #include "serial_tree_learner.h"
 
-#include <LightGBM/utils/array_args.h>
 #include <LightGBM/network.h>
 #include <LightGBM/objective_function.h>
 
+#include <LightGBM/utils/array_args.h>
+
 #include <algorithm>
 #include <vector>
 #include <queue>
@@ -237,7 +238,9 @@ Tree* SerialTreeLearner::FitByExistingTree(const Tree* old_tree, const score_t*
     }
     double output = FeatureHistogram::CalculateSplittedLeafOutput(sum_grad, sum_hess,
                                                                   config_->lambda_l1, config_->lambda_l2, config_->max_delta_step);
-    tree->SetLeafOutput(i, output* tree->shrinkage());
+    auto old_leaf_output = tree->LeafOutput(i);
+    auto new_leaf_output = output * tree->shrinkage();
+    tree->SetLeafOutput(i, config_->refit_decay_rate * old_leaf_output + (1.0 - config_->refit_decay_rate) * new_leaf_output);
     OMP_LOOP_EX_END();
   }
   OMP_THROW_EX();
@@ -773,6 +776,7 @@ void SerialTreeLearner::Split(Tree* tree, int best_leaf, int* left_leaf, int* ri
   }
 }
 
+
 void SerialTreeLearner::RenewTreeOutput(Tree* tree, const ObjectiveFunction* obj, const double* prediction,
                                         data_size_t total_num_data, const data_size_t* bag_indices, data_size_t bag_cnt) const {
   if (obj != nullptr && obj->IsRenewTreeOutput()) {
@@ -782,24 +786,32 @@ void SerialTreeLearner::RenewTreeOutput(Tree* tree, const ObjectiveFunction* obj
       CHECK(bag_cnt == num_data_);
       bag_mapper = bag_indices;
     }
+    std::vector<int> n_nozeroworker_perleaf(tree->num_leaves(), 1);
+    int num_machines = Network::num_machines();
     #pragma omp parallel for schedule(static)
     for (int i = 0; i < tree->num_leaves(); ++i) {
       const double output = static_cast<double>(tree->LeafOutput(i));
       data_size_t cnt_leaf_data = 0;
       auto index_mapper = data_partition_->GetIndexOnLeaf(i, &cnt_leaf_data);
-      CHECK(cnt_leaf_data > 0);
-      // bag_mapper[index_mapper[i]]
-      const double new_output = obj->RenewTreeOutput(output, prediction, index_mapper, bag_mapper, cnt_leaf_data);
-      tree->SetLeafOutput(i, new_output);
+      if (cnt_leaf_data > 0) {
+        // bag_mapper[index_mapper[i]]
+        const double new_output = obj->RenewTreeOutput(output, prediction, index_mapper, bag_mapper, cnt_leaf_data);
+        tree->SetLeafOutput(i, new_output);
+      } else {
+        CHECK(num_machines > 1);
+        tree->SetLeafOutput(i, 0.0);
+        n_nozeroworker_perleaf[i] = 0;
+      }
     }
-    if (Network::num_machines() > 1) {
+    if (num_machines > 1) {
       std::vector<double> outputs(tree->num_leaves());
       for (int i = 0; i < tree->num_leaves(); ++i) {
         outputs[i] = static_cast<double>(tree->LeafOutput(i));
       }
       Network::GlobalSum(outputs);
+      Network::GlobalSum(n_nozeroworker_perleaf);
       for (int i = 0; i < tree->num_leaves(); ++i) {
-        tree->SetLeafOutput(i, outputs[i] / Network::num_machines());
+        tree->SetLeafOutput(i, outputs[i] / n_nozeroworker_perleaf[i]);
       }
     } 
   }
